# 目录结构说明

---

```
├── .electron-vue              # 构建相关(非必要不要修改，修改请先做好源文件备份)
│   ├── log                    # 控制台日志，利用chalk插件。（非必要不更改）
│   ├── plugin                 # vite插件目录
│   │   ├── vite-ikaros-tools.ts           # 参考项目中带的，未测试
│   ├── build.ts               # 构建命令
│   ├── dev-runner.ts          # 开发调试命令
│   ├── hot-updater.ts         # 热更新命令
│   ├── rollup.config.ts       # 回滚命令
│   ├── utils.ts               # 全局设置（从根目录的*.env文件取出运行环境的定义-dotenv插件，如果没有取到，就判定为开发环境），根据运行环境再从env目录取相应的配置文件
│   ├── vite.config.mts        # VITE运行配置，切记不要改为.ts后缀（.mts支持兼容某些插件js的require引用，例如unocss）
├── build                      # 项目打包目录
│   │── icon                   # 图标
│   └── lib                    # 打包依赖（win）
├── config                     # 构建相关的配置
├── dist                       # 构建内容的临时存放目录(每次打包时会先清空该文件夹)
├── env                        # 开发/运行环境相关
│   │── xxx.env                # 环境变量配置
├── fixTypes                   # 自动生成ts语法的auto-import.d.ts（目前未在项目中使用）
├─  public                     # 公共目录（无视）
├─  release                    # 可以将已打包好的版本存放在此（根据自己项目的情况自行考虑），对项目本身无影响
├─ src                         # 源码目录
│  ├─main                      # 主进程目录
│  │  ├──config                # 主进程配置
│  │  │  ├── const             # 静态变量
│  │  │  ├── domains           # 打算用于域名白名单配置的（未启用）
│  │  │  ├── hotPublish        # 热更新配置
│  │  │  ├── staticPath        # 静态路径
│  │  │  └── windowsConfig     # 窗口配置
│  │  ├──handle                # 进程事件定义
│  │  │  ├── browserHandle     # 浏览器进程
│  │  │  ├── mainHandle        # 其他主要进程
│  │  │  ├── serverHanle       # 内置服务器进程
│  │  │  ├── printHanle        # 打印进程
│  │  │  └── serverHanle       # 内置服务器进程
│  │  ├──hooks                 # 事件响应
│  │  │  ├── browser           # 内置浏览器
│  │  │  ├── devTool           # 打开开发者调试窗口
│  │  │  ├── disableButton     # 禁用指定按钮
│  │  │  ├── exception         # 进程渲染响应事件
│  │  │  ├── hotkeys           # 快捷键
│  │  │  ├── menu              # 应用主菜单
│  │  │  ├── print             # 打印功能
│  │  │  └── tray              # 系统托盘
│  │  ├─server                 # 内置服务端文件夹
│  │  │  ├─index               # 内置服务端启停
│  │  │  ├─server              # 内置服务端主体
│  │  │  ├─wsRouters           # 内置Ws服务端路由配置
│  │  │  └─wsServer            # 内置WS服务端主体启停
│  │  ├─services               # 主进程服务文件夹
│  │  │  ├── HotUpdater        # 热更新
│  │  │  ├── checkupdate       # electron-updater
│  │  │  ├── downloadFile      # 下载文件
│  │  │  ├── ipcMain           # ipc通讯
│  │  │  └── windowManager     # 窗口管理
│  │  ├─index.ts               # 主进程入口
│  │  └─ipc.ts                 # IPC相关的ts类定义声明
│  ├─preload                   # 预加载（使渲染进程-子进程可以使用主进程的一些接口）
│  └─renderer                  # 渲染进程文件夹
├── .editorconfig              # 编辑器配置，统一编码风格（可以根据自己的编程习惯来，但强烈建议别修改）
├── tsconfig.json              # typeScript配置
├── updateConfig.json          # update升级配置
├── build.json                 # 项目打包配置
└── package.json               # package.json；推荐使用yarn安装各种包
```

---

---

```
├── renderer                    # 渲染进程补充说明
│   ├─api                   	# 请求以及数据库操作文件夹
│   ├─assets                	# 渲染进程主题 字体等静态资源
│   ├─components            	# 全局公用组件
│   ├─fixTypes              	# TS模块补充
│   ├─i18n                  	# 多语言配置
│   ├─mock         	        	# 本地模拟数据
│   ├─public        	        # 启动页等（非必要不要改）
│   ├─router            	    # 路由（各自定义主题的路由请按规范在主题内添加就好，这里不用修改）
│   ├─store   	                # 全局 store管理
│   ├─styles                    # 全局样式
│   ├─themes          	        # 自定义主题框架
│   │   ├─default          	    # 默认主题框架（UI组件主要使用element-plus)
│   ├─types                 	# 全局TS模块补充
│   ├─utils                 	# 全局公共方法
│   └─views                 	# views 所有页面
│   ├─App*.vue              	# vue主模块（需要自定义的可以复制新建一份修改后再引用即可）
│   ├─error.ts              	# 错误捕捉
│   ├─index.html            	# 入口html
│   ├─interceptor.ts            # 路由权限的基础拦截（更细致的拦截方法可以自行编写，如通过数据库获取等）
│   ├─main-multi-theme.ts       # 自定义主题入口文件


│      ├─icons                 # 项目svg icons
│      ├─layout                # 全局 layout







```

---

# [更新日志](./CHANGELOG.md)
