import {defineStore} from "pinia"

// 需要在头部传入路由表并且在用户登录的时候进行此操作
// 引入路由表
import {constantRouterMap, asyncRoutes} from '@/router'
import {usePermissionStore} from "@theme/store";

/**
 * 通过meta.role判断是否与当前用户权限匹配，此处也可以根据自己的需求进行修改。
 * 只要权限数组有相同项，即视为通过
 * 为安全起见，未配置meta相关参数的则视为无权限
 * @param roles  权限数组 如 ['admin','edit']
 * @param route  要判断的路由 ['edit','guest']
 */
function hasPermission(roles: any[], route) {
	// console.log(roles, route)
	if (route.meta && route.meta.roles) {
		// console.log(route.meta, roles.some(role => route.meta.roles.includes(role)))
		return roles.some(role => route.meta.roles.includes(role));
	}
	return false;
}

/**
 * 递归过滤异步路由表，返回符合用户角色权限的路由表
 * @param routes   需要筛选的路由表
 * @param roles    权限
 */
function filterAsyncRouter(routes: any[], roles: any[]) {
	let res = []
	if (!roles) return res;
	routes.forEach(route => {
		let tmp = {...route}

		if (hasPermission(roles, tmp)) {
			if (tmp.children) {
				tmp.children = filterAsyncRouter(tmp.children, roles)
			}
			res.push(tmp)
		}
	})
	return res
}

// function canPath(roles:any[], path:string) {
//
//     return false;
// }
//
// function filterAsyncPage(roles:any,path:string){
//   let res = []
//     if(!roles) return res;
//     asyncRoutes.forEach(route => {
//         let tmp = { ...route }
//
//         if (hasPermission(roles, tmp)) {
//             if (tmp.children) {
//                 tmp.children = filterAsyncRouter(tmp.children, roles)
//             }
//             res.push(tmp)
//         }
//     })
//     return res
// }

export const useStorePermission = defineStore('permission', {
	state: () => ({
		routers: [],
	}),
	actions: {
		GenerateRoutes(roles: any) {
			//按角色分配可用路径（注意用户角色值是数组，路径适用角色也是数组）
			return new Promise(resolve => {
				let accessedRouters = [];
				// 在这里当是管理员权限时,就给予所有的路由表
				// roles是传入的文本时
				if (roles === 'admin') {
					accessedRouters = asyncRoutes
				} else {
					// roles是传入的数组时
					accessedRouters = filterAsyncRouter(asyncRoutes, roles);
				}
				this.routers = constantRouterMap.concat(accessedRouters);
				resolve(this.routers)
			})
		},
		ResetRoutes() {
			return new Promise(resolve => {
				this.routers = []
				resolve(true)
			})
		},
		checkRoute(roles: any, path: object) {
			//检查路由权限
			return hasPermission(roles, path);
		}
	},
})

export default useStorePermission;
