/**
 * 全路由表（主题目录内的路由，仅需要返回数组即可，交给主框架进行路由重组）
 * 必须依照以下格式配置
 * ：path表示的是路径，如”/“或"/login"或”/redirect/:path(.*)“
 * {
 *   ":path":{
 *     component:"视图组件",
 *     meta:{
 *       hidden: bool 是否隐藏
 *       title: '页标题',
 *       icon: '图标配置，根据自己的主题来自行定义',
 *       roles: ['guest']   权限角色组
 *     },
 *     children:{}  子路径，配置方式与父路径的要求是一样的
 *   }
 * }
 */
const paths = {
	"/login": {
		path: "/login",
		component: () => import("@/themes/_single/views/Login.vue"),
		meta: {
			hidden: true,
			title: "登陆",
			icon: "",
			roles: ["guest"]
		}
	},

	"/": {
		path: "/",
		component: () => import("@/themes/_single/views/LandingPage.vue"),
		// 用于 keep-alive 功能，需要与 SFC 中自动推导或显式声明的组件名称一致
		// 参考文档: https://cn.vuejs.org/guide/built-ins/keep-alive.html#include-exclude
		meta: {
			hidden: false,
			title: "dashboard",
			icon: "homepage",
			affix: true,
			keepAlive: true,
			roles: ["admin", "guest"]
		}
	},

	"/ctms": {
		path: "/ctms",
		component: () => import("@/themes/_single/views/Browser.vue"),
		meta: {
			hidden: true,
			title: "",
			icon: "",
			roles: ["guest"]
		}
	},

	"403": {
		path: "/403",
		component: () => import("@/views/403.vue"),
		meta: {
			hidden: true,
			title: "",
			icon: "",
			roles: ["guest"]
		}
	},

	"404": {
		path: "/404",
		component: () => import("@/views/404.vue"),
		meta: {
			hidden: true,
			title: "",
			icon: "",
			roles: ["guest"]
		}
	},


};

export default paths;
